@@ -1,9 +1,9 @@
 mod cache;
-mod check;
-pub mod checker;
+pub mod check_ast;
+mod check_lines;
+mod checks;
 pub mod fs;
 pub mod linter;
 pub mod logging;
 pub mod message;
-mod parser;
 mod visitor;
