@@ -4,7 +4,7 @@ use colored::Colorize;
 use rustpython_parser::ast::Location;
 use serde::{Deserialize, Serialize};
 
-use crate::check::CheckKind;
+use crate::checks::CheckKind;
 
 #[derive(Serialize, Deserialize)]
 #[serde(remote = "Location")]
@@ -21,7 +21,7 @@ impl From<LocationDef> for Location {
     }
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Debug, PartialEq, Eq, Serialize, Deserialize)]
 pub struct Message {
     pub kind: CheckKind,
     #[serde(with = "LocationDef")]
@@ -33,12 +33,13 @@ impl fmt::Display for Message {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
             f,
-            "{}{}{}{}{}\t{}\t{}",
+            "{}{}{}{}{}{} {} {}",
             self.filename.white().bold(),
             ":".cyan(),
+            self.location.row(),
+            ":".cyan(),
             self.location.column(),
             ":".cyan(),
-            self.location.row(),
             self.kind.code().red().bold(),
             self.kind.body()
         )
